CacheEntry class

/ The CacheEntry class is used to store the cache key and websocket data.

Constructors

CacheEntry(String cacheKey, String websocketData)
The CacheEntry constructor is used to initialize the cache entry.

Properties

cacheKey ↔ String
The cacheKey is the cache key.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
websocketData ↔ String
The websocketData is the websocket data.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited