CacheManager class

Constructors

CacheManager()

Properties

failedKeys ↔ List<CacheEntry>
The failedKeys is a list of failed keys.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
requestedKeys ↔ List<CacheEntry>
The requestedKeys is a list of requested keys.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addFailed(CacheEntry cacheEntry) → void
The addFailed method is called to add a failed key to the requested keys list.
init() → void
The init method is called to initialize the cache manager. It will reset the failed keys and requested keys.
listen(dynamic channel, dynamic cache, bool disconnected) → void
The listen method is called to listen to the websocket channel. It will send a request to the websocket channel every 30 seconds for the failed keys.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited