SecurityIdentifier class

The SecurityIdentifier data represent the identifier of a security. The identifier can be a symbol, ISIN, CUSIP or WKN. At the moment Bavest only supports the symbol.

Constructors

SecurityIdentifier({String? symbol, String? isin, String? cusip, String? wkn})
SecurityIdentifier.fromJson(Map<String, dynamic> json)
factory

Properties

cusip → String?
Identifier by CUSIP currently not supported
final
hashCode → int
The hash code for this object.
no setterinherited
isin → String?
Identifier by ISIN currently not supported
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
symbol → String?
Identifier by symbol
final
wkn → String?
Identifier by WKN currently not supported
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, String>
Returns a map with the identifier as key and the value as value. This is used to provide extensions in future versions.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited